import js from '@eslint/js'
import ts from 'typescript-eslint'
import vue from 'eslint-plugin-vue'
import prettier from 'eslint-plugin-prettier/recommended'
import tailwind from 'eslint-plugin-tailwindcss'
import markdown from "@eslint/markdown";

export const config = ts.config(
    {
        files: ['**/*.{js,mjs,cjs}'],
        ...js.configs.recommended,
    },
    {
        files: ['**/*.{ts,tsx,mjs,cjs}'],
        extends: [
            ...ts.configs.recommended
        ]
    },
    { 
        files: ['**/*.vue'],
        extends: [
            ...vue.configs['flat/recommended'],
            ...vue.configs['flat/essential'],
            ...tailwind.configs['flat/recommended'],
        ]
    },
    {
        files: ['**/*.md'],
        extends: [...markdown.configs.recommended]
    },
    prettier,
    {
        rules: {
            'no-undef': 'off',
            '@typescript-eslint/no-var-requires': 'off',
            '@typescript-eslint/no-explicit-any': 'off',
            '@typescript-eslint/no-unsafe-function-type': 'off',
            '@typescript-eslint/no-empty-object-type': 'off',
            '@typescript-eslint/no-require-imports': 'off',
            'vue/multi-word-component-names': 'off',
            'vue/no-setup-props-destructure': 'off',
            'vue/one-component-per-file': 'off',
            'vue/no-v-html': 'off',
            'vue/no-v-text-v-html-on-component': 'off',
            'vue/require-toggle-inside-transition': 'off',
            'vue/require-explicit-emits': 'off',
            'vue/html-indent': 'off',
            'vue/max-attributes-per-line': 'off',
            'vue/html-self-closing': 'off',
            'tailwindcss/no-custom-classname': 'off',
            'vue/singleline-html-element-content-newline': 'off',
            'linebreak-style': ['error', 'unix'],
            'prettier/prettier': [
                'error',
                {
                    endOfLine: 'auto',
                    trailingComma: 'es5',
                    semi: false,
                    singleQuote: true,
                    useTabs: false,
                    quoteProps: 'consistent',
                    tabWidth: 4,
                    bracketSpacing: true,
                    arrowParens: 'always',
                    printWidth: 100,
                },
            ],
        },
    }
)

